// src/appSlice/constants.ts
import { BarChart as BarChartIcon, PieChartOutline as PieChartIcon } from "@mui/icons-material";
var startingDeviceCount = {
  os: "for first 50 devices",
  professional: "for first 250 devices"
};
var apiRoot = "/api/management";
var apiUrl = {
  v1: `${apiRoot}/v1`,
  v2: `${apiRoot}/v2`
};
var headerNames = {
  link: "link",
  location: "location",
  total: "x-total-count"
};
var chartTypes = {
  bar: { key: "bar", Icon: BarChartIcon },
  pie: { key: "pie", Icon: PieChartIcon }
};
var emptyChartSelection = { software: "", group: "", chartType: chartTypes.bar.key, attribute: "artifact_name" };
var defaultReportType = "distribution";
var defaultReports = [{ ...emptyChartSelection, group: null, attribute: "artifact_name", type: defaultReportType }];
var BEGINNING_OF_TIME = "2016-01-01T00:00:00.000Z";
var locations = {
  eu: { key: "eu", title: "EU", location: "eu.hosted.mender.io" },
  us: { key: "us", title: "US", location: "hosted.mender.io" }
};
var PLANS = {
  os: {
    id: "os",
    name: "Basic",
    offer: true,
    price: "$32/month",
    deviceCount: startingDeviceCount.os,
    offerprice: "$23/month for first 50 devices",
    price2: "for first 6 months;\n$29/month thereafter",
    features: ["Basic OTA features"]
  },
  professional: {
    id: "professional",
    name: "Professional",
    offer: true,
    price: "$269/month",
    deviceCount: startingDeviceCount.professional,
    offerprice: "$200/month for first 50 devices",
    price2: "for first 6 months;\n$249/month thereafter",
    features: ["+ Advanced OTA features", "+ Standard support"]
  },
  enterprise: {
    id: "enterprise",
    name: "Enterprise",
    price: "Custom pricing",
    deviceCount: "unlimited devices",
    features: ["+ Enterprise-grade OTA features", "+ Premium support"]
  }
};
var ADDONS = {
  configure: {
    id: "configure",
    title: "Configure",
    description: "Expand your plan with device configuration features",
    needs: ["hasDeviceConfig"],
    os: {
      price: "$11/month",
      deviceCount: startingDeviceCount.os
    },
    professional: {
      price: "$65/month",
      deviceCount: startingDeviceCount.professional
    },
    eligible: ["os", "professional", "enterprise"]
  },
  troubleshoot: {
    id: "troubleshoot",
    title: "Troubleshoot",
    description: "Expand your plan with device troubleshooting features",
    needs: ["hasDeviceConnect"],
    os: {
      price: "$27/month",
      deviceCount: startingDeviceCount.os
    },
    professional: {
      price: "$72/month",
      deviceCount: startingDeviceCount.professional
    },
    eligible: ["os", "professional", "enterprise"]
  },
  monitor: {
    id: "monitor",
    title: "Monitor",
    description: "Expand your plan with device monitoring features",
    needs: ["hasMonitor"],
    os: {
      price: "-",
      deviceCount: "-"
    },
    professional: {
      price: "$86/month",
      deviceCount: startingDeviceCount.professional
    },
    eligible: ["professional", "enterprise"]
  }
};
var BENEFITS = {
  auditlog: { id: "auditlog", benefit: "trace change across your devices and access troubleshooting session replay", requiredPlan: PLANS.professional.id },
  dashboard: { id: "dashboard", benefit: "actionable insights into the devices you are updating with Mender", requiredPlan: PLANS.enterprise.id },
  deltaGeneration: {
    id: "deltaGeneration",
    benefit: "automatic delta artifacts generation to minimize data transfer and improve the update delivery",
    requiredPlan: PLANS.enterprise.id
  },
  deviceConfiguration: { id: "deviceConfiguration", benefit: "device configuration features", requiredAddon: ADDONS.configure.id },
  deviceMonitor: { id: "deviceMonitor", benefit: "device monitoring features", requiredAddon: ADDONS.monitor.id, requiredPlan: PLANS.professional.id },
  deviceTroubleshoot: { id: "deviceTroubleshoot", benefit: "device troubleshooting features", requiredAddon: ADDONS.troubleshoot.id },
  dynamicGroups: { id: "dynamicGroups", benefit: "create dynamic groups to ease device management", requiredPlan: PLANS.enterprise.id },
  fullFiltering: { id: "fullFiltering", benefit: "filtering by multiple attributes to improve the device overview", requiredPlan: PLANS.professional.id },
  gateway: { id: "gateway", benefit: "see devices connected to your gateway device for easy access", requiredPlans: PLANS.professional.id },
  pausedDeployments: {
    id: "pausedDeployments",
    benefit: "granular control about update rollout to allow synchronization across your fleet",
    requiredPlan: PLANS.enterprise.id
  },
  phasedDeployments: { id: "phasedDeployments", benefit: "choose to roll out deployments in multiple phases", requiredPlan: PLANS.enterprise.id },
  rbac: { id: "rbac", benefit: "granular role based access control", requiredPlan: PLANS.enterprise.id },
  retryDeployments: { id: "retryDeployments", benefit: "optional retries for failed rollout attempts", requiredPlan: PLANS.professional.id },
  scheduledDeployments: {
    id: "scheduledDeployments",
    benefit: "scheduled deployments to steer the distribution of your updates.",
    requiredPlan: PLANS.professional.id
  },
  webhookEvents: {
    id: "webhookEvents",
    benefit: "receive inventory events and select which type(s) of events the webhook will receive",
    requiredPlan: PLANS.professional.id
  },
  default: { id: "default", benefit: "gain access to this feature", requiredPlan: PLANS.enterprise.id }
};
var yes = () => true;
var canAccess = yes;
var DARK_MODE = "dark";
var LIGHT_MODE = "light";
var APPLICATION_JSON_CONTENT_TYPE = "application/json";
var APPLICATION_JWT_CONTENT_TYPE = "application/jwt";

export {
  apiRoot,
  apiUrl,
  headerNames,
  chartTypes,
  emptyChartSelection,
  defaultReportType,
  defaultReports,
  BEGINNING_OF_TIME,
  locations,
  PLANS,
  ADDONS,
  BENEFITS,
  yes,
  canAccess,
  DARK_MODE,
  LIGHT_MODE,
  APPLICATION_JSON_CONTENT_TYPE,
  APPLICATION_JWT_CONTENT_TYPE
};
//# sourceMappingURL=chunk-25AKG5HH.js.map